@@ -126,3 +126,12 @@ class Pool:
 
         # Return a new script instead that runs it on any connection of the pool.
         return Script(script.sha, script.code, lambda: self.evalsha)
+
+    def close(self):
+        """
+        Close all the connections in the pool.
+        """
+        for c in self._connections:
+            c.close()
+
+        self._connections = []
